@@ -13,9 +13,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Shaun McCance <shaunm@gnome.org>
  */
@@ -1067,7 +1065,7 @@ icon_theme_changed (GtkIconTheme *theme,
 	if (info != NULL) {
 	    settings->priv->icons[i] = g_filename_to_uri (gtk_icon_info_get_filename (info),
                                                           NULL, NULL);
-	    gtk_icon_info_free (info);
+	    g_object_unref (info);
 	}
 	else {
 	    settings->priv->icons[i] = NULL;
