@@ -13,9 +13,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Shaun McCance <shaunm@gnome.org>
  */
@@ -543,6 +541,9 @@ yelp_application_add_bookmark (YelpBookmarks     *bookmarks,
     GSettings *settings;
     YelpApplication *app = YELP_APPLICATION (bookmarks);
 
+    g_return_if_fail (page_id);
+    g_return_if_fail (doc_uri);
+
     settings = application_get_doc_settings (app, doc_uri);
 
     if (settings) {
@@ -672,7 +673,8 @@ yelp_application_update_bookmarks (YelpApplication   *app,
         g_variant_iter_free (iter);
 
         if (updated)
-            g_settings_set (settings, "bookmarks", "a(sss)", builder);
+            g_settings_set_value (settings, "bookmarks",
+                                  g_variant_builder_end (&builder));
         else
             g_variant_builder_clear (&builder);
     }
@@ -787,7 +789,13 @@ window_resized (YelpWindow        *window,
     GSettings *settings;
 
     uri = yelp_window_get_uri (window);
+    if (uri == NULL)
+        return FALSE;
     doc_uri = yelp_uri_get_document_uri (uri);
+    if (doc_uri == NULL) {
+        g_object_unref (uri);
+        return FALSE;
+    }
     settings = g_hash_table_lookup (priv->docsettings, doc_uri);
 
     if (settings) {
